(function () {
    window.addEventListener('DOMContentLoaded', (event) => {
        initWK();
        let wkInitCheck = setInterval(function () {
            let statusWrapperEl = document.querySelector("body");
            if (statusWrapperEl) {
                let statusWrapperActiveEl = document.querySelector("body.wkwp-action-active");
                if (statusWrapperActiveEl) {
                    clearInterval(wkInitCheck);
                } else {
                    initWK();
                }
            } else {
                clearInterval(wkInitCheck);
            }
        }, 5000);
    });

    function wkAddLinkActions() {
        const statusWrapperEls = document.querySelector("body");
        if (statusWrapperEls) {
            statusWrapperEls.classList.add('wkwp-action-active');
        }
    }

    function initWK() {
        let wkSettings = window["wallkitSettings"] || {};
        if(typeof wkSettings.integration !== 'undefined' ) {
            window.wk = new WallkitIntegration(wkSettings.integration);

            let wkAuthReady = setInterval(function () {
                if (window.wk.authentication) {
                    clearInterval(wkAuthReady);
                    wkAddLinkActions();
                    wkShowUserStatus();
                    wkCheckPostAccess();
                }
            }, 100);

            window.wk.events.subscribe("success-auth", function ({register}) {
                // Without reloading page
                wkShowUserStatus();
                wkCheckPostAccess();
            });

            window.wk.events.subscribe("wk-event-logout", function () {
                location.reload();
                // Without reloading page
                // wkShowUserStatus();
                // wkCheckPostAccess();
                // window.wk.popup.hide();
            });

            window.wk.events.subscribe("wk-event-transaction", function () {
                // location.reload();
                // Without reloading page
                wkCheckPostAccess();
            });
        }
    }

    function wkShowUserStatus() {
        let wkSettings = window["wallkitSettings"] || {};
        let wkTranslations = window["wallkitTranslations"] || {};
        const accountStatusSpanEls = document.querySelectorAll(".wkwp-user-my-account-button");
        if( !accountStatusSpanEls.length ) {
            return;
        }
        const userAccountBlock = document.querySelectorAll(".wkwp-login-block");

        const imgDefaultSrc = 'https://www.gravatar.com/avatar/?d=mp';
        const accountStatusImgEls = document.querySelectorAll(".wkwp-user-my-account-img");
        const accountSiteLogo = document.querySelectorAll(".wkwp-site-logo");
        let wkCallClass = wkSettings.integration.call.classForHandleClick || 'wk-call';
        if (window.wk.authentication.isAuthenticated()) {
            window.wk.sdk.methods.client.get({
                path: '/user'
            })
                .then((responce) => {
                    if (responce.id > 0 && responce.id === window.wk.sdk.methods.user.id) {
                        window.wk.sdk.methods.user = responce;
                        if( accountStatusImgEls.length > 0 ) {
                            accountStatusImgEls.forEach(element => {
                                element.src = window.wk.sdk.methods.user.photos.image_100;
                                element.classList.remove(wkCallClass, 'wk–sign-in' );
                                element.classList.add(wkCallClass, 'wk–account-settings');
                                element.style = "display:block;";
                            });
                        }

                        if( accountStatusSpanEls.length > 0 ) {
                            accountStatusSpanEls.forEach(element => {
                                element.innerHTML = wkTranslations.my_account || 'My&nbsp;Account'
                                element.classList.remove(wkCallClass, 'wk–sign-in' );
                                element.classList.add(wkCallClass, 'wk–account-settings');
                            });
                        }

                        if( accountSiteLogo.length > 0 ) {
                            accountSiteLogo.forEach(element => {
                                element.style = "display:none;";
                            });
                        }
                    }

                    if(userAccountBlock) {
                        userAccountBlock.style = "display:block;";
                    }
                }, (error) => {
                    console.log('ERROR:', error);
                });
        } else {
            if( accountStatusImgEls.length > 0 ) {
                accountStatusImgEls.forEach(element => {
                    element.src = imgDefaultSrc;
                    element.classList.remove(wkCallClass,'wk–account-settings');
                    element.classList.add(wkCallClass,'wk–sign-in');
                    element.style = "display:none;";
                });
            }

            if( accountStatusSpanEls.length > 0 ) {
                accountStatusSpanEls.forEach(element => {
                    element.classList.remove(wkCallClass,'wk–account-settings');
                    element.classList.add(wkCallClass,'wk–sign-in');
                    element.innerHTML = wkTranslations.sign_in || 'Sign&nbsp;in'
                });
            }

            if( accountSiteLogo.length > 0 ) {
                accountSiteLogo.forEach(element => {
                    element.style = "display:block;";
                });
            }

            if(userAccountBlock) {
                userAccountBlock.style = "display:block;";
            }
        }
    }

    function wkCheckPostAccess() {
        let wkContentBody = '';
        let wkPaywallBlock = '';

        if ( typeof window.wallkitPostData.config !== "undefined"
            && typeof window.wallkitPostData.config.check_post !== "undefined"
            && window.wallkitPostData.config.check_post !== false
            && typeof window.wallkitPostData.data !== "undefined"
            && typeof window.wallkitPostData.data.id !== "undefined"
            && window.wallkitPostData.data.id !== ''
        ) {

            const postInfo = window.wallkitPostData.data;
            const wkPost = new window.wk.content(postInfo);
            const postContentWrapper    = document.querySelector(".wkwp-paywall");
            const postContentBody       = document.querySelector(".wkwp-paywall .wkwp-content-inner");
            let postPaywallBlock        = document.querySelector(".wkwp-paywall .wkwp-paywall-block");

            if(!postContentWrapper) {
                return;
            }

            if(postContentBody && !wkContentBody) {
                wkContentBody = postContentBody.innerHTML;
            }
            if(postPaywallBlock && !wkPaywallBlock) {
                wkPaywallBlock = postPaywallBlock.innerHTML;
            }

            wkPost.checkAccess().then((response) => {
                if (!response.allowed) {
                    if(postContentBody) {
                        postContentBody.innerHTML = build_lorem_content(postContentBody);

                        if (!window.wallkitPostData.config.show_blur) {
                            postContentBody.style = "display:none;";
                        } else {
                            postContentBody.classList.add('wkwp-content-blured');
                        }
                    }

                    if(!postPaywallBlock && wkPaywallBlock) {
                        postPaywallBlock = document.createElement('div');
                        postPaywallBlock.classList.add('wkwp-paywall-block');
                        postPaywallBlock.insertAdjacentHTML('beforeend', wkPaywallBlock)
                        postContentBody.parentNode.insertBefore(postPaywallBlock, postContentBody);
                    }

                    if(postPaywallBlock) {
                        let paywallBlockLoginLink = postPaywallBlock.querySelector('.wallkit-paywall-block__login_plans');
                        if (paywallBlockLoginLink) {
                            if (window.wk.authentication.isAuthenticated()) {
                                paywallBlockLoginLink.style = "display:none;";
                            } else {
                                paywallBlockLoginLink.style = "display:block;";
                            }
                        }
                    }

                    postContentWrapper.style = "display:block;";
                } else {
                    if(postPaywallBlock) {
                        postPaywallBlock.remove();
                    }

                    if(postContentBody) {
                        if(wkContentBody) {
                            postContentBody.innerHTML = wkContentBody;
                        }
                        postContentBody.classList.remove('wkwp-content-blured');
                        postContentBody.style = "display:block;";
                    }
                    postContentWrapper.style = "display:block;";
                }
            }).catch((error) => {
                console.log('!! wkPost ERROR', error);
            });
        }
    }

    function build_lorem_content(el) {
        const loremText = [
            `Inventore molestiae accusantium fuga delectus. Sed exercitationem aut quis reiciendis nesciunt dolore et. Voluptatibus at suscipit eius ratione perspiciatis provident. Totam minima quia occaecati maxime mollitia.`,
            `Laborum occaecati sapiente nesciunt voluptatem. Voluptatibus asperiores optio ut. Pariatur perspiciatis voluptatem beatae commodi libero modi.`,
            `Aut et ipsum beatae tenetur sit. Necessitatibus harum ea et. Natus aut quas sit dolores odio ut. Ipsum sit corporis maxime voluptatum et. Et labore id rerum nobis quia voluptatibus veniam dolores.`,
            `Sed aut repudiandae alias. Sunt est ab dignissimos quasi recusandae labore. Amet vitae illo debitis beatae nesciunt dolor dignissimos. Voluptatum consequuntur error at omnis. Tenetur quaerat facere placeat enim doloribus.`,
            `Id tempora quo placeat dolore. Eos sunt sapiente et facere. Ex facere et voluptate praesentium. Modi mollitia at non eum rerum perferendis. Nobis blanditiis consequatur incidunt.`,
            `Sint voluptas nam sed. Eligendi beatae corporis omnis ipsum facilis dicta a repudiandae. Suscipit et eligendi eveniet ipsum veritatis aut. Aspernatur adipisci fugit deserunt eos hic ut omnis. Corporis et itaque dicta similique.`,
            `Fugit dolores vitae iste qui. Dignissimos quo molestiae cumque. Sequi illo non saepe facere aut aliquid consequuntur sunt. Amet non illo dolor molestiae nulla eligendi quae. Id aut et velit quos sit ratione earum rerum.`,
            `Soluta error neque dolor perspiciatis mollitia. Voluptatem corporis doloribus fugiat et. Unde et rerum magni. Dolores nisi laudantium laboriosam voluptatem.`,
            `Dolores in illo exercitationem est enim pariatur quam corporis. Non ipsa sequi explicabo. Placeat earum aspernatur quod et quia.`,
            `Et sed amet ipsa. Qui et corrupti eaque et at dicta nesciunt vero. Est quasi eius possimus repellat ea ut. Inventore vel et possimus officiis quo consectetur similique. Culpa ut voluptatem non pariatur illum autem sapiente. Et et quidem est dolorum ab.`,
            `Amet id ipsam deleniti minima aut laboriosam. Odio ut reiciendis delectus repudiandae dolorem quaerat. Alias asperiores eum molestiae libero assumenda non voluptatibus quo. Et esse laboriosam ab velit et. Eligendi sint assumenda et.`,
            `Soluta ex voluptas minima et magnam est. Deserunt error molestiae veritatis amet. Quia provident sint molestiae omnis optio sunt sint. Commodi praesentium est perferendis inventore aut atque dolor doloribus. Minima enim velit eaque qui sed non dignissimos debitis. Rerum placeat in qui reprehenderit blanditiis nemo sed.`,
            `Magni dolore enim asperiores quae asperiores. Et quia eligendi ad quo aut labore ut iste. Quia qui esse aperiam eos illum exercitationem minus quod.`,
            `Sed ut dolorum sunt. Tempora incidunt aspernatur doloremque voluptatem quidem voluptatem magni. Est voluptatum minus id. Totam repudiandae reiciendis et.`,
            `Sint natus tenetur qui earum recusandae id optio. Dolore voluptates et accusamus et tempora sint. Dolores reiciendis iusto et quos aut. Sequi et officiis ipsum distinctio. Expedita voluptatibus corporis odio blanditiis iusto.`,
            `Ipsum dolores ut ut. Quia et voluptates accusamus neque quidem exercitationem dignissimos. Libero velit nemo omnis dolores ea repudiandae commodi accusamus. Sint tempore aut officia iste odit odio. Quibusdam sed debitis officiis.`,
            `Voluptatem quo est eius occaecati voluptatem tempore. Iste voluptas animi a voluptatem. Debitis est dolore aut fuga sunt voluptatem itaque assumenda. Id magnam officiis sint recusandae dolorum. Architecto numquam dignissimos quam corporis hic. Sit rerum amet provident.`,
            `Sed eum reiciendis aspernatur ab cupiditate. Ut atque dolores rerum veritatis voluptatem quidem ex voluptatum. Perspiciatis tempore quia quia animi vel distinctio. Id officia odit iusto facilis aliquid sequi eaque. Magnam eaque laudantium et et exercitationem.`,
            `Quod et ut voluptatibus assumenda sed. Nesciunt ea sed asperiores veniam temporibus blanditiis possimus. Quisquam eos voluptas assumenda molestiae.`,
            `Labore ipsum vitae dolorem est sed repellendus. Animi qui sequi similique dolorem sed vel omnis. Rerum saepe id atque animi.`
        ];

        if(el && el.querySelectorAll('p').length > 0 ) {
            let length = el.querySelectorAll('p').length;
            let tempText = [];
            for ( var i = 0; i < length; i++ ) {
                tempText.push( loremText[Math.floor(Math.random() * loremText.length)] );
            }
            tempText = tempText.map(item => `<p>${item}</p>`).join("");

            return tempText;
        }

        return '';
    }

})();